pub struct ServerCommunicationConfigClient {
client: ServerCommunicationConfigClient<UniffiRepositoryBridge<Arc<dyn ServerCommunicationConfigRepository>>, UniffiPlatformApiBridge<Arc<dyn ServerCommunicationConfigPlatformApi>>>,
}Expand description
UniFFI wrapper for ServerCommunicationConfigClient
Fields
client: ServerCommunicationConfigClient<UniffiRepositoryBridge<Arc<dyn ServerCommunicationConfigRepository>>, UniffiPlatformApiBridge<Arc<dyn ServerCommunicationConfigPlatformApi>>>Implementations
Sourceimpl ServerCommunicationConfigClient
impl ServerCommunicationConfigClient
Sourcepub fn new(
repository: Arc<dyn ServerCommunicationConfigRepository>,
platform_api: Arc<dyn ServerCommunicationConfigPlatformApi>,
) -> Arc<Self>
pub fn new( repository: Arc<dyn ServerCommunicationConfigRepository>, platform_api: Arc<dyn ServerCommunicationConfigPlatformApi>, ) -> Arc<Self>
Creates a new server communication configuration client
Sourceimpl ServerCommunicationConfigClient
impl ServerCommunicationConfigClient
Sourcepub async fn get_config(
&self,
hostname: String,
) -> Result<ServerCommunicationConfig>
pub async fn get_config( &self, hostname: String, ) -> Result<ServerCommunicationConfig>
Retrieves the server communication configuration for a hostname
Sourcepub async fn needs_bootstrap(&self, hostname: String) -> bool
pub async fn needs_bootstrap(&self, hostname: String) -> bool
Determines if cookie bootstrapping is needed for this hostname
Returns all cookies that should be included in requests to this server
Sourcepub async fn set_communication_type(
&self,
hostname: String,
config: ServerCommunicationConfig,
) -> Result<()>
pub async fn set_communication_type( &self, hostname: String, config: ServerCommunicationConfig, ) -> Result<()>
Sets the server communication configuration for a hostname
This method saves the provided communication configuration to the repository.
Typically called when receiving the /api/config response from the server.
Acquires a cookie from the platform and saves it to the repository